#Topsis Package
A Python package to implement topsis on a given dataset.
##Usage
Following query on terminal will provide you the best and worst decisions for the dataset.

```
python 101903438.py 101903438.csv "1,1,1,1" "+,+,-,+" resultFileName.csv
```
